@@ -59,7 +59,7 @@ from .jobs import (
     StdStream,
 )
 from .parser import DiskVolume, Parser, SecretFile, Volume
-from .parsing_utils import LocalImage, RemoteImage, TagOption
+from .parsing_utils import LocalImage, RemoteImage, Tag, TagOption
 from .plugins import ConfigBuilder, PluginManager
 from .secrets import Secret, Secrets
 from .server_cfg import Cluster
@@ -68,7 +68,7 @@ from .tracing import gen_trace_id
 from .users import Action, Permission, Share, Users
 from .utils import _ContextManager, find_project_root
 
-__version__ = "21.2.19"
+__version__ = "21.4.2"
 
 
 __all__ = (
@@ -140,6 +140,7 @@ __all__ = (
     "StorageProgressLeaveDir",
     "StorageProgressStart",
     "StorageProgressStep",
+    "Tag",
     "TagOption",
     "Users",
     "Volume",
