@@ -9,6 +9,7 @@ import sqlite3
 import sys
 import time
 from dataclasses import dataclass, replace
+from decimal import Decimal
 from pathlib import Path
 from types import MappingProxyType
 from typing import Any, Dict, Iterator, List, Mapping, Optional, Set, Tuple, Union
@@ -61,6 +62,13 @@ class _ConfigData:
     clusters: Mapping[str, Cluster]
 
 
+@dataclass(frozen=True)
+class _ConfigRecoveryData:
+    url: URL
+    cluster_name: str
+    refresh_token: str
+
+
 class Config(metaclass=NoPublicConstructor):
     def __init__(self, core: _Core, path: Path) -> None:
         self._core = core
@@ -107,15 +115,18 @@ class Config(metaclass=NoPublicConstructor):
 
     @property
     def _cluster(self) -> Cluster:
+        return self.get_cluster(self.cluster_name)
+
+    def get_cluster(self, cluster_name: str) -> Cluster:
         try:
-            return self._config_data.clusters[self.cluster_name]
+            return self._config_data.clusters[cluster_name]
         except KeyError:
             if self._get_user_cluster_name() is None:
                 tip = "Please logout and login again."
             else:
                 tip = "Please edit local user config file or logout and login again."
             raise RuntimeError(
-                f"Cluster {self.cluster_name} doesn't exist in "
+                f"Cluster {cluster_name} doesn't exist in "
                 f"a list of available clusters "
                 f"{list(self._config_data.clusters)}. {tip}"
             ) from None
@@ -362,6 +373,27 @@ def _load(path: Path) -> _ConfigData:
         raise ConfigError(MALFORMED_CONFIG_MSG)
 
 
+def _load_recovery_data(path: Path) -> _ConfigRecoveryData:
+    try:
+        with _open_db_ro(path) as db:
+            cur = db.cursor()
+            # only one row is always present normally
+            cur.execute(
+                """
+                SELECT refresh_token, url, cluster_name
+                FROM main ORDER BY timestamp DESC LIMIT 1"""
+            )
+            payload = cur.fetchone()
+
+        return _ConfigRecoveryData(
+            url=URL(payload["url"]),
+            cluster_name=payload["cluster_name"],
+            refresh_token=payload["refresh_token"],
+        )
+    except (AttributeError, KeyError, TypeError, ValueError, sqlite3.DatabaseError):
+        raise ConfigError(MALFORMED_CONFIG_MSG)
+
+
 def _deserialize_auth_config(payload: Dict[str, Any]) -> _AuthConfig:
     auth_config = json.loads(payload["auth_config"])
     success_redirect_url = auth_config.get("success_redirect_url")
@@ -405,6 +437,7 @@ def _deserialize_resource_preset(payload: Dict[str, Any]) -> Tuple[str, Preset]:
     return (
         payload["name"],
         Preset(
+            credits_per_hour=Decimal(payload["credits_per_hour"]),
             cpu=payload["cpu"],
             memory_mb=payload["memory_mb"],
             gpu=payload.get("gpu"),
@@ -518,6 +551,7 @@ def _serialize_clusters(clusters: Mapping[str, Cluster]) -> str:
 def _serialize_resource_preset(name: str, preset: Preset) -> Dict[str, Any]:
     return {
         "name": name,
+        "credits_per_hour": str(preset.credits_per_hour),
         "cpu": preset.cpu,
         "memory_mb": preset.memory_mb,
         "gpu": preset.gpu,
@@ -633,6 +667,7 @@ def _validate_user_config(
     # validates it.
     plugin_manager = PluginManager()
     plugin_manager.config.define_str("job", "ps-format")
+    plugin_manager.config.define_str("job", "top-format")
     plugin_manager.config.define_str("job", "life-span")
     if allow_cluster_name:
         plugin_manager.config.define_str("job", "cluster-name")
