@@ -1,5 +1,6 @@
 import asyncio
 from dataclasses import replace
+from decimal import Decimal
 from pathlib import Path
 from typing import Callable, Dict, Optional
 
@@ -58,14 +59,27 @@ def cluster_config() -> Cluster:
         disks_url=URL("https://secrets-dev.neu.ro"),
         presets={
             "gpu-small": Preset(
-                cpu=7, memory_mb=30 * 1024, gpu=1, gpu_model="nvidia-tesla-k80"
+                credits_per_hour=Decimal("10"),
+                cpu=7,
+                memory_mb=30 * 1024,
+                gpu=1,
+                gpu_model="nvidia-tesla-k80",
             ),
             "gpu-large": Preset(
-                cpu=7, memory_mb=60 * 1024, gpu=1, gpu_model="nvidia-tesla-v100"
+                credits_per_hour=Decimal("10"),
+                cpu=7,
+                memory_mb=60 * 1024,
+                gpu=1,
+                gpu_model="nvidia-tesla-v100",
+            ),
+            "cpu-small": Preset(
+                credits_per_hour=Decimal("10"), cpu=7, memory_mb=2 * 1024
+            ),
+            "cpu-large": Preset(
+                credits_per_hour=Decimal("10"), cpu=7, memory_mb=14 * 1024
             ),
-            "cpu-small": Preset(cpu=7, memory_mb=2 * 1024),
-            "cpu-large": Preset(cpu=7, memory_mb=14 * 1024),
             "cpu-large-p": Preset(
+                credits_per_hour=Decimal("10"),
                 cpu=7,
                 memory_mb=14 * 1024,
                 scheduler_enabled=True,
@@ -100,17 +114,50 @@ def make_client(
                 disks_url=(url / "disk"),
                 presets={
                     "gpu-small": Preset(
-                        cpu=7, memory_mb=30 * 1024, gpu=1, gpu_model="nvidia-tesla-k80"
+                        credits_per_hour=Decimal("10"),
+                        cpu=7,
+                        memory_mb=30 * 1024,
+                        gpu=1,
+                        gpu_model="nvidia-tesla-k80",
                     ),
                     "gpu-large": Preset(
-                        cpu=7, memory_mb=60 * 1024, gpu=1, gpu_model="nvidia-tesla-v100"
+                        credits_per_hour=Decimal("10"),
+                        cpu=7,
+                        memory_mb=60 * 1024,
+                        gpu=1,
+                        gpu_model="nvidia-tesla-v100",
+                    ),
+                    "cpu-small": Preset(
+                        credits_per_hour=Decimal("10"), cpu=7, memory_mb=2 * 1024
+                    ),
+                    "cpu-large": Preset(
+                        credits_per_hour=Decimal("10"), cpu=7, memory_mb=14 * 1024
                     ),
-                    "cpu-small": Preset(cpu=7, memory_mb=2 * 1024),
-                    "cpu-large": Preset(cpu=7, memory_mb=14 * 1024),
                 },
                 name="default",
             )
-            clusters = {cluster_config.name: cluster_config}
+            cluster2_config = Cluster(
+                registry_url=(url / "registry2"),
+                monitoring_url=(url / "jobs2"),
+                storage_url=(url / "storage2"),
+                blob_storage_url=(url / "blob2"),
+                users_url=url,
+                secrets_url=(url / "secrets2"),
+                disks_url=(url / "disk2"),
+                presets={
+                    "cpu-small": Preset(
+                        credits_per_hour=Decimal("10"), cpu=7, memory_mb=2 * 1024
+                    ),
+                    "cpu-large": Preset(
+                        credits_per_hour=Decimal("10"), cpu=7, memory_mb=14 * 1024
+                    ),
+                },
+                name="another",
+            )
+            clusters = {
+                cluster_config.name: cluster_config,
+                cluster2_config.name: cluster2_config,
+            }
         if token_url is not None:
             real_auth_config = replace(auth_config, token_url=token_url)
         else:
